#' ggeasy.
#'
#' Helper functions for making using ggplot2 easier.
#'
#' @name ggeasy
#' @keywords internal
#' @import ggplot2
"_PACKAGE"
